@@ -240,6 +240,7 @@ fn handles_remove_correctly() {
     let item2 = ([100f64], 2);
     let item3 = ([45f64], 3);
     let item4 = ([55f64], 4);
+    let item5 = ([45f64], 5);
 
     // Build a kd tree
     let capacity_per_node = 2;
@@ -249,13 +250,14 @@ fn handles_remove_correctly() {
     kdtree.add(&item2.0, item2.1).unwrap();
     kdtree.add(&item3.0, item3.1).unwrap();
     kdtree.add(&item4.0, item4.1).unwrap();
+    kdtree.add(&item5.0, item5.1).unwrap();
 
     let num_removed = kdtree.remove(&&item3.0, &item3.1).unwrap();
-    assert_eq!(kdtree.size(), 3);
+    assert_eq!(kdtree.size(), 4);
     assert_eq!(num_removed, 1);
     assert_eq!(
-        kdtree.nearest(&[51f64], 2, &squared_euclidean).unwrap(),
-        vec![(16.0, &4), (2401.0, &2)]
+        kdtree.nearest(&[51f64], 3, &squared_euclidean).unwrap(),
+        vec![(16.0, &4), (36.0, &5), (2401.0, &2)]
     );
 }
 
